@@ -4,12 +4,12 @@
  * See LICENSE.txt for license information
  ************************************************************************/
 
-#include "nccl_device/impl/comm__funcs.h"
 #include "nccl_device/coop.h"
+#include "nccl_device/impl/barrier__funcs.h"
+#include "nccl_device/impl/comm__funcs.h"
 #include "nccl_device/impl/core__funcs.h"
 #include "nccl_device/impl/ll_a2a__funcs.h"
-#include "nccl_device/impl/mem_barrier__funcs.h"
-//#include "nccl_device/net_barrier__funcs.h"
-//#include "nccl_device/net_scratch_a2a__funcs.h"
-//#include "nccl_device/barrier__funcs.h"
+#include "nccl_device/impl/lsa_barrier__funcs.h"
+#include "nccl_device/impl/gin__funcs.h"
+#include "nccl_device/impl/gin_barrier__funcs.h"
 #include "nccl_device/impl/ptr__funcs.h"
